@@ -18,6 +18,7 @@ package mobac.gui;
 
 import java.awt.Container;
 import java.awt.Dimension;
+import java.awt.Font;
 import java.awt.GridBagLayout;
 import java.awt.Toolkit;
 import java.awt.event.ActionEvent;
@@ -45,6 +46,8 @@ import mobac.program.Logging;
 import mobac.program.interfaces.AtlasInterface;
 import mobac.program.interfaces.LayerInterface;
 import mobac.program.interfaces.MapInterface;
+import mobac.program.interfaces.MapSourceListener;
+import mobac.program.model.AtlasOutputFormat;
 import mobac.program.model.Settings;
 import mobac.utilities.GBC;
 import mobac.utilities.GUIExceptionHandler;
@@ -54,11 +57,10 @@ import mobac.utilities.Utilities;
 import org.apache.log4j.Logger;
 
 /**
- * A window showing the progress while {@link AtlasThread} downloads and
- * processes the map tiles.
+ * A window showing the progress while {@link AtlasThread} downloads and processes the map tiles.
  * 
  */
-public class AtlasProgress extends JFrame implements ActionListener {
+public class AtlasProgress extends JFrame implements ActionListener, MapSourceListener {
 
 	private static Logger log = Logger.getLogger(AtlasProgress.class);
 
@@ -80,10 +82,11 @@ public class AtlasProgress extends JFrame implements ActionListener {
 		MapInterface map;
 		MapInfo mapInfo;
 		long numberOfDownloadedBytes = 0;
+		long numberOfBytesLoadedFromCache = 0;
 		int totalNumberOfTiles = 0;
 		int totalNumberOfMaps = 0;
 		int totalProgress = 0;
-		int totalProgressPercent = -1;
+		int totalProgressTenthPercent = -1;
 		int currentMapNumber = 0;
 		int mapDownloadProgress = 0;
 		int mapDownloadNumberOfTiles = 0;
@@ -99,6 +102,7 @@ public class AtlasProgress extends JFrame implements ActionListener {
 	private final Data data = new Data();
 
 	private boolean aborted = false;
+	private boolean finished = false;
 
 	private JLabel windowTitle;
 
@@ -116,14 +120,20 @@ public class AtlasProgress extends JFrame implements ActionListener {
 	private JLabel nrOfDownloadedBytesValue;
 	private JLabel nrOfDownloadedBytesPerSecond;
 	private JLabel nrOfDownloadedBytesPerSecondValue;
+	private JLabel nrOfCacheBytes;
+	private JLabel nrOfCacheBytesValue;
 	private JLabel activeDownloads;
 	private JLabel activeDownloadsValue;
-	private JLabel downloadErrors;
-	private JLabel downloadErrorsValue;
+	private JLabel retryableDownloadErrors;
+	private JLabel retryableDownloadErrorsValue;
+	private JLabel permanentDownloadErrors;
+	private JLabel permanentDownloadErrorsValue;
 	private JLabel totalDownloadTime;
 	private JLabel totalDownloadTimeValue;
 
 	private JCheckBox ignoreDlErrors;
+	private JLabel statusLabel;
+
 	private JButton dismissWindowButton;
 	private JButton openProgramFolderButton;
 	private JButton abortAtlasCreationButton;
@@ -138,23 +148,30 @@ public class AtlasProgress extends JFrame implements ActionListener {
 
 	private ArrayList<MapInfo> mapInfos = null;
 
-	private static String TEXT_MAP_DOWNLOAD = "Downloading tiles for map number ";
-	private static String TEXT_PERCENT = "Percent done: %d%%";
+	private static String TEXT_MAP_DOWNLOAD = "Collecting tiles for zoom level ";
+	private static String TEXT_PERCENT = "%d%% done";
+	private static String TEXT_TENTHPERCENT = "%.1f%% done";
 
 	public AtlasProgress(AtlasThread atlasThread) {
 		super("Atlas creation in progress");
 		this.atlasThread = atlasThread;
 		ToolTipManager.sharedInstance().setDismissDelay(12000);
+		if (MainGUI.getMainGUI() == null) // Atlas creation started via command-line, no MainGUi available
+			setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
+		else
+			setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
+
 		setIconImages(MainGUI.MOBAC_ICONS);
 		setLayout(new GridBagLayout());
 		updateTask = new UpdateTask();
 		guiUpdater = new GUIUpdater();
 
 		createComponents();
-
 		// Initialize the layout in respect to the layout (font size ...)
 		pack();
 
+		guiUpdater.run();
+
 		// The layout is now initialized - we disable it because we don't want
 		// want to the labels to jump around if the content changes.
 		background.setLayout(null);
@@ -177,10 +194,11 @@ public class AtlasProgress extends JFrame implements ActionListener {
 
 		title = new JLabel("Processing maps of atlas:");
 
-		mapInfoLabel = new JLabel("Processing map: ");
+		mapInfoLabel = new JLabel("Processing map ABCDEFGHIJKLMNOPQRSTUVWXYZ-nn "
+				+ "of layer ABCDEFGHIJKLMNOPQRSTUVWXYZ from map source ABCDEFGHIJKLMNOPQRSTUVWXYZ");
 
 		atlasMapsDone = new JLabel("000 of 000 done");
-		atlasPercent = new JLabel(String.format(TEXT_PERCENT, 100));
+		atlasPercent = new JLabel(String.format(TEXT_TENTHPERCENT, 100.0));
 		atlasTimeLeft = new JLabel("Time remaining: 00000 minutes 00 seconds", JLabel.RIGHT);
 		atlasProgressBar = new JProgressBar();
 
@@ -195,23 +213,33 @@ public class AtlasProgress extends JFrame implements ActionListener {
 
 		nrOfDownloadedBytesPerSecond = new JLabel("Average download speed");
 		nrOfDownloadedBytesPerSecondValue = new JLabel();
-		nrOfDownloadedBytes = new JLabel("Total download size");
+		nrOfDownloadedBytes = new JLabel("Downloaded");
 		nrOfDownloadedBytesValue = new JLabel();
+		nrOfCacheBytes = new JLabel("Loaded from tile store");
+		nrOfCacheBytesValue = new JLabel();
+
 		activeDownloads = new JLabel("Active tile fetcher threads");
 		activeDownloadsValue = new JLabel();
-		downloadErrors = new JLabel("Download errors");
-		downloadErrors
-				.setToolTipText("<html><h4>Download errors for the current map and for the total atlas (retryable/permanent)</h4>"
-						+ "<p>Mobile Atlas Creator tries to retry failed tile downloads up to two times.<br>"
-						+ "The first time a tile download fails the <b>retryable</b> counter increases by one.<br>"
+		retryableDownloadErrors = new JLabel("Transient download errors");
+		retryableDownloadErrors
+				.setToolTipText("<html><h4>Download errors for the current map and for the total atlas (transient/unrecoverable)</h4>"
+						+ "<p>Mobile Atlas Creator retries failed tile downloads up to two times. <br>"
 						+ "If the tile downloads fails the second time the tile will be counted as <br>"
-						+ "<b>permanent</b> error and not tried again.<br></p></html>");
-		downloadErrorsValue = new JLabel();
-		downloadErrorsValue.setToolTipText(downloadErrors.getToolTipText());
+						+ "<b>unrecoverable</b> error and not tried again during the current map creation run.<br></p></html>");
+		retryableDownloadErrorsValue = new JLabel();
+		retryableDownloadErrorsValue.setToolTipText(retryableDownloadErrors.getToolTipText());
+		permanentDownloadErrors = new JLabel("Unrecoverable download errors");
+		permanentDownloadErrors.setToolTipText(retryableDownloadErrors.getToolTipText());
+		permanentDownloadErrorsValue = new JLabel();
+		permanentDownloadErrorsValue.setToolTipText(permanentDownloadErrors.getToolTipText());
 		totalDownloadTime = new JLabel("Total creation time");
 		totalDownloadTimeValue = new JLabel();
 
-		ignoreDlErrors = new JCheckBox("Ignore download errors and continue automatically");
+		ignoreDlErrors = new JCheckBox("Ignore download errors and continue automatically",
+				Settings.getInstance().ignoreDlErrors);
+		statusLabel = new JLabel("Status:");
+		Font f = statusLabel.getFont();
+		statusLabel.setFont(f.deriveFont(Font.BOLD));
 		abortAtlasCreationButton = new JButton("Abort creation");
 		abortAtlasCreationButton.setToolTipText("Abort current Atlas download");
 		dismissWindowButton = new JButton("Close Window");
@@ -255,19 +283,25 @@ public class AtlasProgress extends JFrame implements ActionListener {
 		GBC gbci = GBC.std().insets(0, 3, 3, 3);
 		infoPanel.add(nrOfDownloadedBytes, gbci);
 		infoPanel.add(nrOfDownloadedBytesValue, gbci.toggleEol());
+		infoPanel.add(nrOfCacheBytes, gbci.toggleEol());
+		infoPanel.add(nrOfCacheBytesValue, gbci.toggleEol());
 		infoPanel.add(nrOfDownloadedBytesPerSecond, gbci.toggleEol());
 		infoPanel.add(nrOfDownloadedBytesPerSecondValue, gbci.toggleEol());
 		infoPanel.add(activeDownloads, gbci.toggleEol());
 		infoPanel.add(activeDownloadsValue, gbci.toggleEol());
-		infoPanel.add(downloadErrors, gbci.toggleEol());
-		infoPanel.add(downloadErrorsValue, gbci.toggleEol());
+		infoPanel.add(retryableDownloadErrors, gbci.toggleEol());
+		infoPanel.add(retryableDownloadErrorsValue, gbci.toggleEol());
+		infoPanel.add(permanentDownloadErrors, gbci.toggleEol());
+		infoPanel.add(permanentDownloadErrorsValue, gbci.toggleEol());
 		infoPanel.add(totalDownloadTime, gbci.toggleEol());
 		infoPanel.add(totalDownloadTimeValue, gbci.toggleEol());
 
 		JPanel bottomPanel = new JPanel(new GridBagLayout());
-		bottomPanel.add(infoPanel, GBC.std().gridheight(2));
+		bottomPanel.add(infoPanel, GBC.std().gridheight(2).fillH());
 		bottomPanel.add(ignoreDlErrors, GBC.eol().anchor(GBC.EAST));
 
+		bottomPanel.add(statusLabel, GBC.eol().anchor(GBC.CENTER));
+
 		GBC gbcRight = GBC.std().anchor(GBC.SOUTHEAST).insets(5, 0, 0, 0);
 		bottomPanel.add(Box.createHorizontalGlue(), GBC.std().fill(GBC.HORIZONTAL));
 		bottomPanel.add(abortAtlasCreationButton, gbcRight);
@@ -290,7 +324,10 @@ public class AtlasProgress extends JFrame implements ActionListener {
 
 	public void initAtlas(AtlasInterface atlasInterface) {
 		data.atlasInterface = atlasInterface;
-		data.totalNumberOfTiles = atlasInterface.calculateTilesToDownload() * 2;
+		if (atlasInterface.getOutputFormat().equals(AtlasOutputFormat.TILESTORE))
+			data.totalNumberOfTiles = (int) atlasInterface.calculateTilesToDownload();
+		else
+			data.totalNumberOfTiles = (int) atlasInterface.calculateTilesToDownload() * 2;
 		int mapCount = 0;
 		int tileCount = 0;
 		mapInfos = new ArrayList<MapInfo>(100);
@@ -298,7 +335,7 @@ public class AtlasProgress extends JFrame implements ActionListener {
 			mapCount += layer.getMapCount();
 			for (MapInterface map : layer) {
 				int before = tileCount;
-				int mapTiles = map.calculateTilesToDownload();
+				int mapTiles = (int) map.calculateTilesToDownload();
 				tileCount += mapTiles + mapTiles;
 				mapInfos.add(new MapInfo(map, before, tileCount));
 			}
@@ -318,7 +355,7 @@ public class AtlasProgress extends JFrame implements ActionListener {
 		data.mapInfo = mapInfos.get(index);
 		data.totalProgress = data.mapInfo.tileCountOnStart;
 		data.map = map;
-		data.mapDownloadNumberOfTiles = map.calculateTilesToDownload();
+		data.mapDownloadNumberOfTiles = (int) map.calculateTilesToDownload();
 		initialMapDownloadTime = System.currentTimeMillis();
 		data.prevMapsPermanentErrors += data.mapPermanentErrors;
 		data.prevMapsRetryErrors += data.mapRetryErrors;
@@ -328,6 +365,11 @@ public class AtlasProgress extends JFrame implements ActionListener {
 		updateGUI();
 	}
 
+	/**
+	 * Initialize the GUI progress bars
+	 * 
+	 * @param maxTilesToProcess
+	 */
 	public void initMapCreation(int maxTilesToProcess) {
 		data.mapCreationProgress = 0;
 		data.mapCreationMax = maxTilesToProcess;
@@ -357,43 +399,42 @@ public class AtlasProgress extends JFrame implements ActionListener {
 
 	public void setMapCreationProgress(int progress) {
 		data.mapCreationProgress = progress;
-		data.totalProgress = data.mapInfo.tileCountOnStart + data.mapInfo.mapTiles
-				+ (data.mapInfo.mapTiles * data.mapCreationProgress / data.mapCreationMax);
+		long creationProgressTiles = data.totalProgress = data.mapInfo.tileCountOnStart + data.mapInfo.mapTiles
+				+ (int) (((long) data.mapInfo.mapTiles) * data.mapCreationProgress / data.mapCreationMax);
 		updateGUI();
 	}
 
-	public void addDownloadedBytes(int bytes) {
-		data.numberOfDownloadedBytes += bytes;
-	}
-
 	public boolean ignoreDownloadErrors() {
 		return ignoreDlErrors.isSelected();
 	}
 
-	private String formatRemainingTime(long seconds) {
-		int minutesLeft = 0;
-		String timeLeftString;
-
-		if (seconds < 0) {
-			timeLeftString = "unknown";
-		} else if (seconds > 60) {
-			minutesLeft = (int) (seconds / 60);
-			int secondsLeft = (int) (seconds % 60);
-			if (secondsLeft > 119) {
-				timeLeftString = Integer.toString(minutesLeft) + " " + "minutes" + " "
-						+ Integer.toString(secondsLeft) + " " + "seconds";
-			} else {
-				timeLeftString = Integer.toString(minutesLeft) + " " + "minute" + " "
-						+ Integer.toString(secondsLeft) + " " + "seconds";
-			}
-		} else {
-			if (seconds > 1) {
-				timeLeftString = Long.toString(seconds) + " " + "seconds";
-			} else {
-				timeLeftString = Long.toString(seconds) + " " + "second";
-			}
+	public void tileDownloaded(int size) {
+		synchronized (data) {
+			data.numberOfDownloadedBytes += size;
 		}
-		return "Time remaining: " + timeLeftString;
+		updateGUI();
+	}
+
+	public void tileLoadedFromCache(int size) {
+		synchronized (data) {
+			data.numberOfBytesLoadedFromCache += size;
+		}
+		updateGUI();
+	}
+
+	private String formatTime(long longSeconds) {
+		String timeString = "";
+
+		if (longSeconds < 0) {
+			timeString = "unknown";
+		} else {
+			int minutes = (int) (longSeconds / 60);
+			int seconds = (int) (longSeconds % 60);
+			if (minutes > 0)
+				timeString += Integer.toString(minutes) + " " + (minutes == 1 ? "minute" : "minutes") + " ";
+			timeString += Integer.toString(seconds) + " " + (seconds == 1 ? "second" : "seconds");
+		}
+		return timeString;
 	}
 
 	public void setZoomLevel(int theZoomLevel) {
@@ -401,22 +442,23 @@ public class AtlasProgress extends JFrame implements ActionListener {
 	}
 
 	public void atlasCreationFinished() {
+		finished = true;
 		stopUpdateTask();
+		forceUpdateGUI();
 		downloadControlListener = null;
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
 				abortAtlasCreationButton.setEnabled(false);
 
 				if (aborted) {
-					windowTitle.setText("<html><h2>ATLAS CREATION HAS BEEN "
-							+ "ABORTED BY USER</h2></html>");
+					windowTitle.setText("<html><h2>ATLAS CREATION HAS BEEN " + "ABORTED BY USER</h2></html>");
 					setTitle("Atlas creation aborted");
 				} else {
-					windowTitle.setText("<html><h2>ATLAS CREATION FINISHED "
-							+ "SUCCESSFULLY</h2></html>");
+					windowTitle.setText("<html><h2>ATLAS CREATION FINISHED " + "SUCCESSFULLY</h2></html>");
 					setTitle("Atlas creation finished successfully");
 				}
-				mapInfoLabel.setText("");
+				// mapInfoLabel.setText("");
+				atlasMapsDone.setText(data.currentMapNumber + " of " + data.totalNumberOfMaps + " done");
 
 				abortAtlasCreationButton.setVisible(false);
 
@@ -471,11 +513,11 @@ public class AtlasProgress extends JFrame implements ActionListener {
 			closeWindow();
 		} else if (abortAtlasCreationButton.equals(source)) {
 			aborted = true;
-			updateTask.cancel();
-			if (downloadControlListener != null) {
+			stopUpdateTask();
+			if (downloadControlListener != null)
 				downloadControlListener.abortAtlasCreation();
-			} else
-				dispose();
+			else
+				closeWindow();
 		} else if (pauseResumeDownloadButton.equals(source)) {
 			if (downloadControlListener != null)
 				downloadControlListener.pauseResumeAtlasCreation();
@@ -486,6 +528,10 @@ public class AtlasProgress extends JFrame implements ActionListener {
 		guiUpdater.updateAsynchronously();
 	}
 
+	public void forceUpdateGUI() {
+		SwingUtilities.invokeLater(guiUpdater);
+	}
+
 	private class GUIUpdater implements Runnable {
 
 		int scheduledCounter = 0;
@@ -508,9 +554,9 @@ public class AtlasProgress extends JFrame implements ActionListener {
 			}
 
 			if (data.map != null) {
-				String text = "<html>Processing map \"<b>" + data.map.getName()
-						+ "</b>\" of layer <b>\"" + data.map.getLayer().getName()
-						+ "\"</b> map source: " + data.map.getMapSource() + "</html>";
+				String text = "<html>Processing map <b>" + data.map.getName() + "</b> " + "of layer <b>"
+						+ data.map.getLayer().getName() + "</b> " + "from map source <b>" + data.map.getMapSource()
+						+ "</b></html>";
 				mapInfoLabel.setText(text);
 			}
 
@@ -518,20 +564,35 @@ public class AtlasProgress extends JFrame implements ActionListener {
 			atlasProgressBar.setMaximum(data.totalNumberOfTiles);
 			atlasProgressBar.setValue(data.totalProgress);
 
-			int newPercent = (int) (atlasProgressBar.getPercentComplete() * 100);
-			boolean pauseState = atlasThread.isPaused();
-			if (data.totalProgressPercent != newPercent || pauseState != data.paused) {
-				data.totalProgressPercent = newPercent;
-				atlasPercent.setText(String.format(TEXT_PERCENT, data.totalProgressPercent));
-				if (data.atlasInterface != null) {
-					String text = String.format("%d%% - Processing atlas \"%s\"",
-							data.totalProgressPercent, data.atlasInterface.getName());
-					if (pauseState)
-						text += " [PAUSED]";
-					AtlasProgress.this.setTitle(text);
+			int newTenthPercent = (int) (data.totalProgress * 1000d / (double) data.totalNumberOfTiles);
+			try {
+				boolean pauseState = atlasThread.isPaused();
+				String statusText = "RUNNING";
+				if (aborted)
+					statusText = "ABORTED";
+				else if (finished)
+					statusText = "FINISHED";
+				else if (pauseState)
+					statusText = "PAUSED";
+				else
+					statusText = "RUNNING";
+				statusLabel.setText("Status: " + statusText);
+
+				if (data.totalProgressTenthPercent != newTenthPercent || pauseState != data.paused) {
+					data.totalProgressTenthPercent = newTenthPercent;
+					atlasPercent.setText(String.format(TEXT_TENTHPERCENT, data.totalProgressTenthPercent / 10.0));
+					if (data.atlasInterface != null) {
+						String text = String.format(TEXT_PERCENT + " - processing atlas \"%s\" of type %s",
+								data.totalProgressTenthPercent / 10, data.atlasInterface.getName(),
+								data.atlasInterface.getOutputFormat());
+						if (pauseState)
+							text += " [PAUSED]";
+						AtlasProgress.this.setTitle(text);
+					}
 				}
+				data.paused = pauseState;
+			} catch (NullPointerException e) {
 			}
-			data.paused = pauseState;
 
 			long seconds = -1;
 			int totalProgress = data.totalProgress;
@@ -541,14 +602,14 @@ public class AtlasProgress extends JFrame implements ActionListener {
 				long totalElapsedTime = System.currentTimeMillis() - initialTotalTime;
 				seconds = (totalElapsedTime * totalTilesRemaining / (1000L * totalProgress));
 			}
-			atlasTimeLeft.setText(formatRemainingTime(seconds));
+			atlasTimeLeft.setText("Time remaining: " + formatTime(seconds));
 
 			// layer progress
 			mapDownloadProgressBar.setMaximum(data.mapDownloadNumberOfTiles);
 			mapDownloadProgressBar.setValue(data.mapDownloadProgress);
 
-			mapDownloadPercent.setText(String.format(TEXT_PERCENT, (int) (mapDownloadProgressBar
-					.getPercentComplete() * 100)));
+			mapDownloadPercent.setText(String.format(TEXT_PERCENT,
+					(int) (mapDownloadProgressBar.getPercentComplete() * 100)));
 
 			mapDownloadElementsDone.setText(Integer.toString(data.mapDownloadProgress) + " of "
 					+ data.mapDownloadNumberOfTiles + " tiles done");
@@ -558,51 +619,33 @@ public class AtlasProgress extends JFrame implements ActionListener {
 			if (mapDlProgress != 0 && initialMapDownloadTime > 0)
 				seconds = ((System.currentTimeMillis() - initialMapDownloadTime)
 						* (data.mapDownloadNumberOfTiles - mapDlProgress) / (1000L * mapDlProgress));
-			mapDownloadTimeLeft.setText(formatRemainingTime(seconds));
+			mapDownloadTimeLeft.setText("Time remaining: " + formatTime(seconds));
 
 			// map progress
 			mapCreation.setText("Map creation");
 			mapCreationProgressBar.setValue(data.mapCreationProgress);
 			mapCreationProgressBar.setMaximum(data.mapCreationMax);
-			atlasMapsDone
-					.setText(data.currentMapNumber + " of " + data.totalNumberOfMaps + " done");
+			atlasMapsDone.setText((data.currentMapNumber - 1) + " of " + data.totalNumberOfMaps + " done");
 
 			// bytes per second
 			long rate = data.numberOfDownloadedBytes * 1000;
 			long time = System.currentTimeMillis() - initialMapDownloadTime;
 			if (data.mapCreationProgress == 0 && initialMapDownloadTime > 0) {
 				if (time == 0) {
-					nrOfDownloadedBytesPerSecondValue.setText(": ?? KiByte / Second");
+					nrOfDownloadedBytesPerSecondValue.setText(": ?? KiByte / second");
 				} else {
 					rate = rate / time;
-					nrOfDownloadedBytesPerSecondValue.setText(": " + Utilities.formatBytes(rate)
-							+ " / Second");
+					nrOfDownloadedBytesPerSecondValue.setText(": " + Utilities.formatBytes(rate) + " / second");
 				}
 			}
 
 			// downloaded bytes
-			nrOfDownloadedBytesValue.setText(": "
-					+ Utilities.formatBytes(data.numberOfDownloadedBytes));
+			nrOfDownloadedBytesValue.setText(": " + Utilities.formatBytes(data.numberOfDownloadedBytes));
+			nrOfCacheBytesValue.setText(": " + Utilities.formatBytes(data.numberOfBytesLoadedFromCache));
 
 			// total creation time
-			String timeString = "";
-
-			seconds = 0;
-			long minutes = 0;
-
-			long totalMilliseconds = 0;
-
-			totalMilliseconds = System.currentTimeMillis() - initialTotalTime;
-
-			if (totalMilliseconds > 60000) {
-				minutes = totalMilliseconds / 60000;
-				seconds = (totalMilliseconds - (minutes * 60000)) / 1000;
-				timeString = minutes + " minute(s) and " + seconds + " second(s)";
-			} else {
-				seconds = totalMilliseconds / 1000;
-				timeString = seconds + " second(s)";
-			}
-			totalDownloadTimeValue.setText(": " + timeString);
+			long totalSeconds = (System.currentTimeMillis() - initialTotalTime) / 1000;
+			totalDownloadTimeValue.setText(": " + formatTime(totalSeconds));
 			totalDownloadTimeValue.repaint();
 
 			// active downloads
@@ -610,12 +653,14 @@ public class AtlasProgress extends JFrame implements ActionListener {
 			activeDownloadsValue.setText(": " + activeDownloads);
 			activeDownloadsValue.repaint();
 
+			int totalRetryableErrors = data.prevMapsRetryErrors + data.mapRetryErrors;
+			retryableDownloadErrorsValue.setText(": current map: " + data.mapRetryErrors + ", total: "
+					+ totalRetryableErrors);
+			retryableDownloadErrorsValue.repaint();
 			int totalPermanentErrors = data.prevMapsPermanentErrors + data.mapPermanentErrors;
-			int totalRetylableErrors = data.prevMapsRetryErrors + data.mapRetryErrors;
-			downloadErrorsValue.setText(": map: " + data.mapRetryErrors + " / "
-					+ data.mapPermanentErrors + " total: " + totalRetylableErrors + " / "
+			permanentDownloadErrorsValue.setText(": current map: " + data.mapPermanentErrors + ", total: "
 					+ totalPermanentErrors);
-			downloadErrorsValue.repaint();
+			permanentDownloadErrorsValue.repaint();
 		}
 	}
 
@@ -651,7 +696,7 @@ public class AtlasProgress extends JFrame implements ActionListener {
 			this.map = map;
 			this.tileCountOnStart = tileCountOnStart;
 			this.tileCountOnEnd = tileCountOnEnd;
-			this.mapTiles = map.calculateTilesToDownload();
+			this.mapTiles = (int) map.calculateTilesToDownload();
 		}
 
 		@Override
