@@ -29,6 +29,8 @@ import javax.swing.JOptionPane;
 import mobac.mapsources.custom.StandardMapSourceLayer;
 import mobac.mapsources.impl.DebugLocalMapSource;
 import mobac.mapsources.impl.DebugMapSource;
+import mobac.mapsources.impl.DebugRandomLocalMapSource;
+import mobac.mapsources.impl.DebugTransparentLocalMapSource;
 import mobac.mapsources.impl.SimpleMapSource;
 import mobac.mapsources.loader.BeanShellMapSourceLoader;
 import mobac.mapsources.loader.CustomMapSourceLoader;
@@ -63,6 +65,8 @@ public class DefaultMapSourcesManager extends MapSourcesManager {
 			if (devMode) {
 				addMapSource(new DebugMapSource());
 				addMapSource(new DebugLocalMapSource());
+				addMapSource(new DebugTransparentLocalMapSource());
+				addMapSource(new DebugRandomLocalMapSource());
 			}
 			File mapSourcesDir = Settings.getInstance().getMapSourcesDirectory();
 			if (mapSourcesDir == null)
@@ -197,7 +201,6 @@ public class DefaultMapSourcesManager extends MapSourcesManager {
 		if (mapSources.size() == 0)
 			mapSources.add(new SimpleMapSource());
 		return mapSources;
-
 	}
 
 	@Override
