@@ -21,6 +21,7 @@ import java.io.IOException;
 import java.sql.Connection;
 import java.sql.DriverManager;
 import java.sql.PreparedStatement;
+import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
 import java.util.Locale;
@@ -59,12 +60,16 @@ import mobac.utilities.jdbc.SQLiteLoader;
 @SupportedParameters(names = { Name.format })
 public class RMapsSQLite extends AtlasCreator implements RequiresSQLite {
 
+	private static final int MAX_BATCH_SIZE = 1000;
+
 	private static final String TABLE_DDL = "CREATE TABLE IF NOT EXISTS tiles (x int, y int, z int, s int, image blob, PRIMARY KEY (x,y,z,s))";
 	private static final String INDEX_DDL = "CREATE INDEX IF NOT EXISTS IND on tiles (x,y,z,s)";
 	private static final String INSERT_SQL = "INSERT or REPLACE INTO tiles (x,y,z,s,image) VALUES (?,?,?,0,?)";
 	private static final String RMAPS_TABLE_INFO_DDL = "CREATE TABLE IF NOT EXISTS info AS SELECT 99 AS minzoom, 0 AS maxzoom";
 	private static final String RMAPS_CLEAR_INFO_SQL = "DELETE FROM info;";
-	private static final String RMAPS_UPDATE_INFO_SQL = "INSERT INTO info SELECT MIN(z) as minzoom, MAX(z) as maxzoom FROM tiles;";
+	private static final String RMAPS_UPDATE_INFO_MINMAX_SQL = "INSERT INTO info (minzoom,maxzoom) VALUES (?,?);";
+	private static final String RMAPS_INFO_MAX_SQL = "SELECT DISTINCT z FROM tiles ORDER BY z DESC LIMIT 1;";
+	private static final String RMAPS_INFO_MIN_SQL = "SELECT DISTINCT z FROM tiles ORDER BY z ASC LIMIT 1;";
 
 	protected File databaseFile;
 
@@ -157,7 +162,7 @@ public class RMapsSQLite extends AtlasCreator implements RequiresSQLite {
 	}
 
 	protected void createTiles() throws InterruptedException, MapCreationException {
-		int maxMapProgress = (xMax - xMin + 1) * (yMax - yMin + 1);
+		int maxMapProgress = 2 * (xMax - xMin + 1) * (yMax - yMin + 1);
 		atlasProgress.initMapCreation(maxMapProgress);
 		TileImageParameters param = map.getParameters();
 		if (param != null)
@@ -165,6 +170,7 @@ public class RMapsSQLite extends AtlasCreator implements RequiresSQLite {
 		try {
 			conn.setAutoCommit(false);
 			int batchTileCount = 0;
+			int tilesWritten = 0;
 			Runtime r = Runtime.getRuntime();
 			long heapMaxSize = r.maxMemory();
 			prepStmt = conn.prepareStatement(getTileInsertSQL());
@@ -176,17 +182,18 @@ public class RMapsSQLite extends AtlasCreator implements RequiresSQLite {
 						byte[] sourceTileData = mapDlTileProvider.getTileData(x, y);
 						if (sourceTileData != null) {
 							writeTile(x, y, zoom, sourceTileData);
+							tilesWritten++;
 							long heapAvailable = heapMaxSize - r.totalMemory() + r.freeMemory();
 
 							batchTileCount++;
-							if (heapAvailable < HEAP_MIN) {
+							if ((heapAvailable < HEAP_MIN) || (batchTileCount >= MAX_BATCH_SIZE)) {
 								log.trace("Executing batch containing " + batchTileCount + " tiles");
 								prepStmt.executeBatch();
 								prepStmt.clearBatch();
 								System.gc();
-								batchTileCount = 0;
 								conn.commit();
 								atlasProgress.incMapCreationProgress(batchTileCount);
+								batchTileCount = 0;
 							}
 						}
 					} catch (IOException e) {
@@ -197,8 +204,9 @@ public class RMapsSQLite extends AtlasCreator implements RequiresSQLite {
 			prepStmt.executeBatch();
 			prepStmt.clearBatch();
 			System.gc();
-			updateTileMetaInfo();
-			log.trace("Final commit");
+			if (tilesWritten > 0)
+				updateTileMetaInfo();
+			log.trace("Final commit containing " + batchTileCount + " tiles");
 			conn.commit();
 			atlasProgress.setMapCreationProgress(maxMapProgress);
 		} catch (SQLException e) {
@@ -208,10 +216,24 @@ public class RMapsSQLite extends AtlasCreator implements RequiresSQLite {
 
 	protected void updateTileMetaInfo() throws SQLException {
 		Statement stat = conn.createStatement();
-		stat.addBatch(RMAPS_CLEAR_INFO_SQL);
-		stat.addBatch(RMAPS_UPDATE_INFO_SQL);
-		stat.executeBatch();
+		ResultSet rs = stat.executeQuery(RMAPS_INFO_MAX_SQL);
+		if (!rs.next())
+			throw new SQLException("failed to retrieve max tile zoom info");
+		int max = rs.getInt(1);
+		rs.close();
+		rs = stat.executeQuery(RMAPS_INFO_MIN_SQL);
+		if (!rs.next())
+			throw new SQLException("failed to retrieve min tile zoom info");
+		int min = rs.getInt(1);
+		rs.close();
+		PreparedStatement ps = conn.prepareStatement(RMAPS_UPDATE_INFO_MINMAX_SQL);
+		ps.setInt(1, min);
+		ps.setInt(2, max);
+
+		stat.execute(RMAPS_CLEAR_INFO_SQL);
+		ps.execute();
 		stat.close();
+		ps.close();
 	}
 
 	protected void writeTile(int x, int y, int z, byte[] tileData) throws SQLException, IOException {
