@@ -56,7 +56,7 @@ public class GUIExceptionHandler implements Thread.UncaughtExceptionHandler, Exc
 
 	private static final double MB_DIV = 1024d * 1024d;
 
-	private static final String URL_BUGTRACKER = "http://sourceforge.net/tracker/?group_id=238075&atid=1105494";
+	private static final String URL_BUGTRACKER = "http://sourceforge.net/p/mobac/bugs/";
 
 	static {
 		Thread.setDefaultUncaughtExceptionHandler(instance);
@@ -182,10 +182,8 @@ public class GUIExceptionHandler implements Thread.UncaughtExceptionHandler, Exc
 				sb.append("\nDistribution name: " + dist);
 
 			sb.append("\nJava VM: " + prop("java.vm.name") + " (" + prop("java.runtime.version") + ")");
-			if (t != null && t.getClass().equals(java.lang.OutOfMemoryError.class)) {
-				Runtime r = Runtime.getRuntime();
-				sb.append(String.format("\nMax heap size: %3.2f MiB", r.maxMemory() / MB_DIV));
-			}
+			Runtime r = Runtime.getRuntime();
+			sb.append(String.format("\nMax heap size: %3.2f MiB", r.maxMemory() / MB_DIV));
 			// sb.append("\nMapsources rev: " + MapSourcesUpdater.getCurrentMapSourcesRev());
 
 			sb.append("\nCPU cores: " + Runtime.getRuntime().availableProcessors());
@@ -222,7 +220,7 @@ public class GUIExceptionHandler implements Thread.UncaughtExceptionHandler, Exc
 				sb.append("\n#############################################################");
 
 				guiText = "An unexpected exception occurred (" + exceptionName + ")<br>"
-						+ "<p>Please report a ticket in the bug tracker " + "on <a href=\"" + URL_BUGTRACKER
+						+ "<p>Please create a ticket in the bug tracker " + "on <a href=\"" + URL_BUGTRACKER
 						+ "\">SourceForge.net</a><br>"
 						+ "<b>Please include a detailed description of your performed actions <br>"
 						+ "before the error occurred.</b></p>Be sure to include the following information:";
@@ -285,16 +283,37 @@ public class GUIExceptionHandler implements Thread.UncaughtExceptionHandler, Exc
 	}
 
 	public static void installToolkitEventQueueProxy() {
-		EventQueue queue = Toolkit.getDefaultToolkit().getSystemEventQueue();
-		queue.push(new EventQueueProxy());
+
+		boolean isLikeJava7 = Float.parseFloat(System.getProperty("java.specification.version")) > 1.6;
+
+		EventQueueProxy eventQueueProxy = new EventQueueProxy();
+		// Bug handling. See
+		// http://stackoverflow.com/questions/3158254/how-to-replace-the-awt-eventqueue-with-own-implementation
+		try {
+			if (isLikeJava7)
+				EventQueue.invokeAndWait(eventQueueProxy);
+			else
+				eventQueueProxy.run();
+		} catch (Exception e) {
+			log.error("", e);
+		}
 	}
 
 	/**
 	 * Catching all Runtime Exceptions in Swing
 	 * 
-	 * http://ruben42.wordpress.com/2009/03/30/catching-all-runtime-exceptions- in-swing/
+	 * http://ruben42.wordpress.com/2009/03/30/catching-all-runtime-exceptions-in-swing/
 	 */
-	protected static class EventQueueProxy extends EventQueue {
+	protected static class EventQueueProxy extends EventQueue implements Runnable {
+
+		/**
+		 * Installs the {@link EventQueueProxy}
+		 */
+		@Override
+		public void run() {
+			EventQueue queue = Toolkit.getDefaultToolkit().getSystemEventQueue();
+			queue.push(this);
+		}
 
 		protected void dispatchEvent(AWTEvent newEvent) {
 			try {
@@ -322,7 +341,7 @@ public class GUIExceptionHandler implements Thread.UncaughtExceptionHandler, Exc
 				UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
 				throw new RuntimeException("Test", new Exception("Inner"));
 			} catch (Exception e) {
-				showExceptionDialog("Test 123",e);
+				showExceptionDialog("Test 123", e);
 			} catch (Error e) {
 				showExceptionDialog(e);
 			}
